==> open-xchange-util-custom_1.2.0.orig.tar.bz2: open-xchange-util-custom-1.2.0/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/DispatcherPrefixServiceTrackerCustomizer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.util.activator.impl;

import javax.annotation.Nullable;
import javax.annotation.ParametersAreNonnullByDefault;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.dispatcher.DispatcherPrefixService;


/**
 * {@link DispatcherPrefixServiceRegisterer}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v7.8.2
 */
@ParametersAreNonnullByDefault
public abstract class DispatcherPrefixServiceTrackerCustomizer implements ServiceTrackerCustomizer<DispatcherPrefixService, DispatcherPrefixService> {
    
    private final BundleContext bundleContext;
    
    public DispatcherPrefixServiceTrackerCustomizer(BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }
    
    @Override
    public @Nullable DispatcherPrefixService addingService(final @Nullable ServiceReference<DispatcherPrefixService> reference) {
        final DispatcherPrefixService service = bundleContext.getService(reference);
        if (service != null) {
            try {
                onDispatcherPrefixServiceAvailable(service);
                return service;
            } catch (final Exception e) {
                bundleContext.ungetService(reference);
                return null;
            }
        } else {
            return null;
        }
    }
    @Override
    public void modifiedService(@Nullable ServiceReference<DispatcherPrefixService> reference, @Nullable DispatcherPrefixService service) {
    }
    @Override
    public void removedService(@Nullable ServiceReference<DispatcherPrefixService> reference, @Nullable DispatcherPrefixService service) {
        if (reference != null) {
            bundleContext.ungetService(reference);
        }
    }
    protected abstract void onDispatcherPrefixServiceAvailable(final DispatcherPrefixService dispatcherPrefixService) throws Exception;
}

==> open-xchange-util-custom_1.3.4.orig.tar.bz2: open-xchange-util-custom-1.3.4/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/DispatcherPrefixServiceTrackerCustomizer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.util.activator.impl;



import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.annotation.Nullable;
import com.openexchange.dispatcher.DispatcherPrefixService;


/**
 * {@link DispatcherPrefixServiceRegisterer}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v7.8.2
 */
public abstract class DispatcherPrefixServiceTrackerCustomizer implements ServiceTrackerCustomizer<DispatcherPrefixService, DispatcherPrefixService> {
    
    private final BundleContext bundleContext;
    
    public DispatcherPrefixServiceTrackerCustomizer(BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }
    
    @Override
    public @Nullable DispatcherPrefixService addingService(final @Nullable ServiceReference<DispatcherPrefixService> reference) {
        final DispatcherPrefixService service = bundleContext.getService(reference);
        if (service != null) {
            try {
                onDispatcherPrefixServiceAvailable(service);
                return service;
            } catch (final Exception e) {
                bundleContext.ungetService(reference);
                return null;
            }
        } else {
            return null;
        }
    }
    @Override
    public void modifiedService(@Nullable ServiceReference<DispatcherPrefixService> reference, @Nullable DispatcherPrefixService service) {
    }
    @Override
    public void removedService(@Nullable ServiceReference<DispatcherPrefixService> reference, @Nullable DispatcherPrefixService service) {
        if (reference != null) {
            bundleContext.ungetService(reference);
        }
    }
    protected abstract void onDispatcherPrefixServiceAvailable(final DispatcherPrefixService dispatcherPrefixService) throws Exception;
}
